@@ -1389,12 +1389,19 @@ Array<T>::maybe_delete_elements_2 (idx_vector& idx_arg)
   octave_idx_type nr = dim1 ();
   octave_idx_type nc = dim2 ();
 
+  if (idx_arg.is_colon ())
+    {
+      // A(:) = [] always gives 0-by-0 matrix, even if A was empty.
+      resize_no_fill (0, 0);
+      return;
+    }
+
   octave_idx_type n;
   if (nr == 1)
     n = nc;
   else if (nc == 1)
     n = nr;
-  else
+  else if (! idx_arg.orig_empty ())
     {
       // Reshape to row vector for Matlab compatibility.
 
@@ -1402,20 +1409,20 @@ Array<T>::maybe_delete_elements_2 (idx_vector& idx_arg)
       nr = 1;
       nc = n;
     }
-
-  if (nr > 0 && nc > 0 && idx_arg.is_colon_equiv (n, 1))
-    {
-      // Either A(:) = [] or A(idx) = [] with idx enumerating all
-      // elements, so we delete all elements and return [](0x0).  To
-      // preserve the orientation of the vector, you have to use
-      // A(idx,:) = [] (delete rows) or A(:,idx) (delete columns).
-
-      resize_no_fill (0, 0);
-      return;
-    }
+  else
+    return;
 
   idx_arg.sort (true);
 
+  if (idx_arg.is_colon_equiv (n, 1))
+    {
+      if (nr == 1)
+        resize_no_fill (1, 0);
+      else if (nc == 1)
+        resize_no_fill (0, 1);
+      return;
+    }
+
   octave_idx_type num_to_delete = idx_arg.length (n);
 
   if (num_to_delete != 0)
@@ -1485,167 +1492,133 @@ Array<T>::maybe_delete_elements (idx_vector& idx_i, idx_vector& idx_j)
   octave_idx_type nr = dim1 ();
   octave_idx_type nc = dim2 ();
 
-  if (nr == 0 && nc == 0)
-    return;
-
-  if (idx_i.is_colon ())
+  if (idx_i.is_colon () && idx_j.is_colon ())
     {
-      if (idx_j.is_colon ())
-	{
-	  // A(:,:) -- We are deleting columns and rows, so the result
-	  // is [](0x0).
-
-	  resize_no_fill (0, 0);
-	  return;
-	}
-
-      if (idx_j.is_colon_equiv (nc, 1))
-	{
-	  // A(:,j) -- We are deleting columns by enumerating them,
-	  // If we enumerate all of them, we should have zero columns
-	  // with the same number of rows that we started with.
-
-	  resize_no_fill (nr, 0);
-	  return;
-	}
-    }
-
-  if (idx_j.is_colon () && idx_i.is_colon_equiv (nr, 1))
-    {
-      // A(i,:) -- We are deleting rows by enumerating them.  If we
-      // enumerate all of them, we should have zero rows with the
-      // same number of columns that we started with.
-
+      // A special case: A(:,:). Matlab gives 0-by-nc here, but perhaps we
+      // should not?
       resize_no_fill (0, nc);
-      return;
     }
-
-  if (idx_i.is_colon_equiv (nr, 1))
+  else if (idx_i.is_colon ())
     {
+      idx_j.sort (true); // sort in advance to speed-up the following check
+
       if (idx_j.is_colon_equiv (nc, 1))
-	resize_no_fill (0, 0);
+	resize_no_fill (nr, 0);
       else
 	{
-	  idx_j.sort (true);
-
 	  octave_idx_type num_to_delete = idx_j.length (nc);
 
 	  if (num_to_delete != 0)
-	    {
-	      if (nr == 1 && num_to_delete == nc)
-		resize_no_fill (0, 0);
-	      else
-		{
-		  octave_idx_type new_nc = nc;
+            {
+              octave_idx_type new_nc = nc;
 
-		  octave_idx_type iidx = 0;
+              octave_idx_type iidx = 0;
 
-		  for (octave_idx_type j = 0; j < nc; j++)
-		    if (j == idx_j.elem (iidx))
-		      {
-			iidx++;
-			new_nc--;
+              for (octave_idx_type j = 0; j < nc; j++)
+                if (j == idx_j.elem (iidx))
+                  {
+                    iidx++;
+                    new_nc--;
 
-			if (iidx == num_to_delete)
-			  break;
-		      }
+                    if (iidx == num_to_delete)
+                      break;
+                  }
 
-		  if (new_nc > 0)
-		    {
-		      T *new_data = new T [nr * new_nc];
+              if (new_nc > 0)
+                {
+                  T *new_data = new T [nr * new_nc];
 
-		      octave_idx_type jj = 0;
-		      iidx = 0;
-		      for (octave_idx_type j = 0; j < nc; j++)
-			{
-			  if (iidx < num_to_delete && j == idx_j.elem (iidx))
-			    iidx++;
-			  else
-			    {
-			      for (octave_idx_type i = 0; i < nr; i++)
-				new_data[nr*jj+i] = xelem (i, j);
-			      jj++;
-			    }
-			}
+                  octave_idx_type jj = 0;
+                  iidx = 0;
+                  for (octave_idx_type j = 0; j < nc; j++)
+                    {
+                      if (iidx < num_to_delete && j == idx_j.elem (iidx))
+                        iidx++;
+                      else
+                        {
+                          for (octave_idx_type i = 0; i < nr; i++)
+                            new_data[nr*jj+i] = xelem (i, j);
+                          jj++;
+                        }
+                    }
 
-		      if (--(Array<T>::rep)->count <= 0)
-			delete Array<T>::rep;
+                  if (--(Array<T>::rep)->count <= 0)
+                    delete Array<T>::rep;
 
-		      Array<T>::rep = new typename Array<T>::ArrayRep (new_data, nr * new_nc);
+                  Array<T>::rep = new typename Array<T>::ArrayRep (new_data, nr * new_nc);
 
-		      dimensions.resize (2);
-		      dimensions(1) = new_nc;
-		    }
-		  else
-		    (*current_liboctave_error_handler)
-		      ("A(idx) = []: index out of range");
-		}
-	    }
+                  dimensions.resize (2);
+                  dimensions(1) = new_nc;
+                }
+              else
+                (*current_liboctave_error_handler)
+                  ("A(idx) = []: index out of range");
+            }
 	}
     }
-  else if (idx_j.is_colon_equiv (nc, 1))
+  else if (idx_j.is_colon ())
     {
+      idx_i.sort (true); // sort in advance to speed-up the following check
+
       if (idx_i.is_colon_equiv (nr, 1))
-	resize_no_fill (0, 0);
+	resize_no_fill (0, nc);
       else
 	{
-	  idx_i.sort (true);
-
 	  octave_idx_type num_to_delete = idx_i.length (nr);
 
 	  if (num_to_delete != 0)
-	    {
-	      if (nc == 1 && num_to_delete == nr)
-		resize_no_fill (0, 0);
-	      else
-		{
-		  octave_idx_type new_nr = nr;
+            {
+              octave_idx_type new_nr = nr;
 
-		  octave_idx_type iidx = 0;
+              octave_idx_type iidx = 0;
 
-		  for (octave_idx_type i = 0; i < nr; i++)
-		    if (i == idx_i.elem (iidx))
-		      {
-			iidx++;
-			new_nr--;
+              for (octave_idx_type i = 0; i < nr; i++)
+                if (i == idx_i.elem (iidx))
+                  {
+                    iidx++;
+                    new_nr--;
 
-			if (iidx == num_to_delete)
-			  break;
-		      }
+                    if (iidx == num_to_delete)
+                      break;
+                  }
 
-		  if (new_nr > 0)
-		    {
-		      T *new_data = new T [new_nr * nc];
+              if (new_nr > 0)
+                {
+                  T *new_data = new T [new_nr * nc];
 
-		      octave_idx_type ii = 0;
-		      iidx = 0;
-		      for (octave_idx_type i = 0; i < nr; i++)
-			{
-			  if (iidx < num_to_delete && i == idx_i.elem (iidx))
-			    iidx++;
-			  else
-			    {
-			      for (octave_idx_type j = 0; j < nc; j++)
-				new_data[new_nr*j+ii] = xelem (i, j);
-			      ii++;
-			    }
-			}
+                  octave_idx_type ii = 0;
+                  iidx = 0;
+                  for (octave_idx_type i = 0; i < nr; i++)
+                    {
+                      if (iidx < num_to_delete && i == idx_i.elem (iidx))
+                        iidx++;
+                      else
+                        {
+                          for (octave_idx_type j = 0; j < nc; j++)
+                            new_data[new_nr*j+ii] = xelem (i, j);
+                          ii++;
+                        }
+                    }
 
-		      if (--(Array<T>::rep)->count <= 0)
-			delete Array<T>::rep;
+                  if (--(Array<T>::rep)->count <= 0)
+                    delete Array<T>::rep;
 
-		      Array<T>::rep = new typename Array<T>::ArrayRep (new_data, new_nr * nc);
+                  Array<T>::rep = new typename Array<T>::ArrayRep (new_data, new_nr * nc);
 
-		      dimensions.resize (2);
-		      dimensions(0) = new_nr;
-		    }
-		  else
-		    (*current_liboctave_error_handler)
-		      ("A(idx) = []: index out of range");
-		}
-	    }
+                  dimensions.resize (2);
+                  dimensions(0) = new_nr;
+                }
+              else
+                (*current_liboctave_error_handler)
+                  ("A(idx) = []: index out of range");
+            }
 	}
     }
+  else if (! (idx_i.orig_empty () || idx_j.orig_empty ()))
+    {
+      (*current_liboctave_error_handler)
+        ("a null assignment can have only one non-colon index");
+    }
 }
 
 template <class T>
@@ -1661,6 +1634,21 @@ Array<T>::maybe_delete_elements (Array<idx_vector>& ra_idx, const T& rfv)
 {
   octave_idx_type n_idx = ra_idx.length ();
 
+  // Special case matrices
+  if (ndims () == 2)
+    {
+      if (n_idx == 1)
+        {
+          maybe_delete_elements (ra_idx (0));
+          return;
+        }
+      else if (n_idx == 2)
+        {
+          maybe_delete_elements (ra_idx (0), ra_idx (1));
+          return;
+        }
+    }
+
   dim_vector lhs_dims = dims ();
 
   int n_lhs_dims = lhs_dims.length ();
@@ -1701,6 +1689,7 @@ Array<T>::maybe_delete_elements (Array<idx_vector>& ra_idx, const T& rfv)
 
   for (octave_idx_type i = 0; i < n_idx; i++)
     {
+      if (ra_idx(i).orig_empty ()) return;
       idx_is_colon_equiv(i) = ra_idx(i).is_colon_equiv (lhs_dims(i), 1);
 
       idx_is_colon(i) = ra_idx(i).is_colon ();
@@ -1756,18 +1745,15 @@ Array<T>::maybe_delete_elements (Array<idx_vector>& ra_idx, const T& rfv)
   if (idx_ok)
     {
       if (n_idx > 1
-	  && (all_ones (idx_is_colon) || all_ones (idx_is_colon_equiv)))
+	  && (all_ones (idx_is_colon)))
 	{
 	  // A(:,:,:) -- we are deleting elements in all dimensions, so
 	  // the result is [](0x0x0).
 
-	  dim_vector zeros;
-	  zeros.resize (n_idx);
+	  dim_vector newdim = dims ();
+          newdim(0) = 0;
 
-	  for (int i = 0; i < n_idx; i++)
-	    zeros(i) = 0;
-
-	  resize (zeros, rfv);
+	  resize (newdim, rfv);
 	}
 
       else if (n_idx > 1
@@ -2037,8 +2023,12 @@ Array<T>::value (void) const
       retval = index (idx[0]);
     }
   else
-    (*current_liboctave_error_handler)
-      ("Array<T>::value: invalid number of indices specified");
+    {
+      clear_index ();
+
+      (*current_liboctave_error_handler)
+	("Array<T>::value: invalid number of indices specified");
+    }
 
   clear_index ();
 
@@ -2561,6 +2551,8 @@ assign1 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	    }
 	  else
 	    {
+	      lhs.clear_index ();
+
 	      (*current_liboctave_error_handler)
 		("A(I) = X: X must be a scalar or a vector with same length as I");
 
@@ -2569,6 +2561,8 @@ assign1 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	}
       else
 	{
+	  lhs.clear_index ();
+
 	  (*current_liboctave_error_handler)
 	    ("A(I) = X: unable to resize A");
 
@@ -2589,11 +2583,17 @@ assign1 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	    lhs.xelem (i) = rhs.elem (i);
 	}
       else if (rhs_len != lhs_len)
-	(*current_liboctave_error_handler)
-	  ("A(:) = X: A must be the same size as X");
+	{
+	  lhs.clear_index ();
+
+	  (*current_liboctave_error_handler)
+	    ("A(:) = X: A must be the same size as X");
+	}
     }
   else if (! (rhs_len == 1 || rhs_len == 0))
     {
+      lhs.clear_index ();
+
       (*current_liboctave_error_handler)
 	("A([]) = X: X must also be an empty matrix or a scalar");
 
@@ -2655,6 +2655,7 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	  break;
 
 	default:
+	  lhs.clear_index ();
 	  (*current_liboctave_error_handler)
 	    ("Array<T>::assign2: Dimension mismatch");
 	  return 0;
@@ -2769,6 +2770,8 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 		{
 		  if (! (rhs_is_scalar || (rhs_nr == 0 || rhs_nc == 0)))
 		    {
+		      lhs.clear_index ();
+
 		      (*current_liboctave_error_handler)
 		("A([], []) = X: X must be an empty matrix or a scalar");
 
@@ -2777,12 +2780,10 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 		}
 	      else
 		{
+		  lhs.clear_index ();
+
 		  (*current_liboctave_error_handler)
-    ("A(I, J) = X: X must be a scalar or the number of elements in I must");
-		  (*current_liboctave_error_handler)
-    ("match the number of rows in X and the number of elements in J must");
-		  (*current_liboctave_error_handler)
-    ("match the number of columns in X");
+    ("A(I, J) = X: X must be a scalar or the number of elements in I must match the number of rows in X and the number of elements in J must match the number of columns in X");
 
 		  retval = 0;
 		}
@@ -2900,8 +2901,14 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	      else if (len == 0)
 		{
 		  if (! (rhs_is_scalar || (rhs_nr == 0 || rhs_nc == 0)))
-		    (*current_liboctave_error_handler)
-		      ("A([]) = X: X must be an empty matrix or scalar");
+		    {
+		      lhs.clear_index ();
+
+		      (*current_liboctave_error_handler)
+			("A([]) = X: X must be an empty matrix or scalar");
+
+		      retval = 0;
+		    }
 		}
 	      else if (len == rhs_nr * rhs_nc)
 		{
@@ -2943,6 +2950,8 @@ assign2 (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 		}
 	      else
 		{
+		  lhs.clear_index ();
+
 		  (*current_liboctave_error_handler)
       ("A(I) = X: X must be a scalar or a matrix with the same size as I");
 
@@ -2989,6 +2998,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
     }
   else if (n_idx == 0)
     {
+      lhs.clear_index ();
+
       (*current_liboctave_error_handler)
 	("invalid number of indices for matrix expression");
 
@@ -3015,6 +3026,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	    {
 	      if (! (rhs_dims.all_ones () || rhs_dims.any_zero ()))
 		{
+		  lhs.clear_index ();
+
 		  (*current_liboctave_error_handler)
 		    ("A([]) = X: X must be an empty matrix or scalar");
 
@@ -3063,6 +3076,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	    }
 	  else
 	    {
+	      lhs.clear_index ();
+
 	      (*current_liboctave_error_handler)
 		("A(I) = X: X must be a scalar or a matrix with the same size as I");
 
@@ -3174,6 +3189,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 		    }
 		  else if (new_dims_numel != rhs_dims_numel || new_dims_vec > 1)
 		    {
+		      lhs.clear_index ();
+
 		      (*current_liboctave_error_handler)
 			("A(IDX-LIST) = RHS: mismatched index and RHS dimension");
 		      return retval;
@@ -3201,6 +3218,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 			k++;
 		      else if (nelem != 1)
 			{
+			  lhs.clear_index ();
+
 			  (*current_liboctave_error_handler)
 			    ("A(IDX-LIST) = RHS: mismatched index and RHS dimension");
 			  return retval;
@@ -3243,6 +3262,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 	      // be an error, because we don't know how to undo that
 	      // later...
 
+	      lhs.clear_index ();
+
 	      (*current_liboctave_error_handler)
 		("array index %d (= %d) for assignment requires invalid resizing operation",
 		 n_idx, new_dims(n_idx-1));
@@ -3369,6 +3390,8 @@ assignN (Array<LT>& lhs, const Array<RT>& rhs, const LT& rfv)
 
 		  if (n != rhs.numel ())
 		    {
+		      lhs.clear_index ();
+
 		      (*current_liboctave_error_handler)
 			("A(IDX-LIST) = X: X must be a scalar or size of X must equal number of elements indexed by IDX-LIST");
 
