@@ -1,5 +1,6 @@
 /*
 Copyright (C) 2003, 2004, 2005, 2006, 2007 David Bateman
+Copyright (C) 2008 Jaroslav Hajek
 
 This file is part of Octave.
 
@@ -27,6 +28,12 @@ made are
 * convert the sorting code in listobject.cc into a generic class, 
   replacing PyObject* with the type of the class T.
 
+* replaced usages of malloc, free, memcpy and memmove by standard C++
+  new [], delete [] and std::copy and std::copy_backward. Note that replacing
+  memmove by std::copy is possible if the destination starts before the source.
+  If not, std::copy_backward needs to be used.
+  
+
 The Python license is
 
   PSF LICENSE AGREEMENT FOR PYTHON 2.3
@@ -84,7 +91,8 @@ The Python license is
 #endif
 
 #include <cassert>
-#include <cstdlib>
+#include <algorithm>
+#include <cstring>
 
 #include "lo-mappers.h"
 #include "quit.h"
@@ -431,8 +439,7 @@ template <class T>
 void
 octave_sort<T>::merge_freemem (void)
 {
-  if (ms.a)
-    free (ms.a);
+  delete [] ms.a;
   ms.alloced = 0;
   ms.a = 0;
 }
@@ -489,7 +496,7 @@ octave_sort<T>::merge_getmem (int need)
    * we don't care what's in the block.
    */
   merge_freemem ();
-  ms.a = static_cast <T *> (malloc (need * sizeof (T)));
+  ms.a = new T[need];
   if (ms.a)
     {
       ms.alloced = need;
@@ -519,7 +526,7 @@ octave_sort<T>::merge_lo (T *pa, int na, T *pb, int nb)
 
   if (MERGE_GETMEM (na) < 0)
     return -1;
-  memcpy (ms.a, pa, na * sizeof (T));
+  std::copy (pa, pa + na, ms.a);
   dest = pa;
   pa = ms.a;
 
@@ -581,7 +588,7 @@ octave_sort<T>::merge_lo (T *pa, int na, T *pb, int nb)
 	    {
 	      if (k < 0)
 		goto Fail;
-	      memcpy (dest, pa, k * sizeof (T));
+              std::copy (pa, pa + k, dest);
 	      dest += k;
 	      pa += k;
 	      na -= k;
@@ -605,7 +612,7 @@ octave_sort<T>::merge_lo (T *pa, int na, T *pb, int nb)
 	    {
 	      if (k < 0)
 		goto Fail;
-	      memmove (dest, pb, k * sizeof (T));
+              std::copy (pb, pb + k, dest);
 	      dest += k;
 	      pb += k;
 	      nb -= k;
@@ -628,12 +635,12 @@ octave_sort<T>::merge_lo (T *pa, int na, T *pb, int nb)
 
  Fail:
   if (na)
-    memcpy (dest, pa, na * sizeof (T));
+    std::copy (pa, pa + na, dest);
   return result;
 
  CopyB:
   /* The last element of pa belongs at the end of the merge. */
-  memmove (dest, pb, nb * sizeof (T));
+  std::copy (pb, pb + nb, dest);
   dest[nb] = *pa;
 
   return 0;
@@ -659,7 +666,7 @@ octave_sort<T>::merge_hi (T *pa, int na, T *pb, int nb)
   if (MERGE_GETMEM (nb) < 0)
     return -1;
   dest = pb + nb - 1;
-  memcpy (ms.a, pb, nb * sizeof (T));
+  std::copy (pb, pb + nb, ms.a);
   basea = pa;
   baseb = ms.a;
   pb = ms.a + nb - 1;
@@ -725,7 +732,7 @@ octave_sort<T>::merge_hi (T *pa, int na, T *pb, int nb)
 	    {
 	      dest -= k;
 	      pa -= k;
-	      memmove (dest+1, pa+1, k * sizeof (T));
+              std::copy_backward (pa+1, pa+1 + k, dest+1 + k);
 	      na -= k;
 	      if (na == 0)
 		goto Succeed;
@@ -744,7 +751,7 @@ octave_sort<T>::merge_hi (T *pa, int na, T *pb, int nb)
 	    {
 	      dest -= k;
 	      pb -= k;
-	      memcpy (dest+1, pb+1, k * sizeof (T));
+              std::copy (pb+1, pb+1 + k, dest+1);
 	      nb -= k;
 	      if (nb == 1)
 		goto CopyA;
@@ -769,14 +776,14 @@ Succeed:
 
 Fail:
   if (nb)
-    memcpy (dest-(nb-1), baseb, nb * sizeof (T));
+    std::copy (baseb, baseb + nb, dest-(nb-1));
   return result;
 
 CopyA:
   /* The first element of pb belongs at the front of the merge. */
   dest -= na;
   pa -= na;
-  memmove (dest+1, pa+1, na * sizeof (T));
+  std::copy_backward (pa+1, pa+1 + na, dest+1 + na);
   *dest = *pb;
 
   return 0;
