@@ -1,12 +1,14 @@
 /*
 
-Copyright (C) 2004 David Bateman
-Copyright (C) 1998-2004 Andy Adler
+Copyright (C) 2004, 2005, 2006, 2007 David Bateman
+Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Andy Adler
+
+This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -14,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; see the file COPYING.  If not, write to the
-Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-Boston, MA 02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -28,15 +29,26 @@ Boston, MA 02110-1301, USA.
 class
 octave_sparse_sort_idxl
 {
- public:
-  unsigned int r;
-  unsigned int c;
-  unsigned int idx; 
+public:
+  octave_idx_type r;
+  octave_idx_type c;
+  octave_idx_type idx; 
 };
 
 bool octave_sparse_sidxl_comp (octave_sparse_sort_idxl* i,
 			       octave_sparse_sort_idxl* j);
 
+class
+octave_idx_vector_sort
+{
+public:
+  octave_idx_type i;
+  octave_idx_type idx;
+};
+
+bool octave_idx_vector_comp (octave_idx_vector_sort* i,
+			     octave_idx_vector_sort* j);
+
 #endif
 
 /*
