@@ -1,5 +1,5 @@
 ## Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2002, 2003,
-##               2004, 2005, 2006, 2007 John W. Eaton
+##               2004, 2005, 2006, 2007, 2008 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -109,6 +109,7 @@ function ret = __imagesc__ (ax, x, y, A, limits, DEPRECATEDZOOM)
   endif
 
   ret = image (ax, x, y, A);
+  set (ret, "cdatamapping", "scaled")
 
   ## use given limits or guess them from the matrix
   if (length (limits) == 2 && limits(2) >= limits(1))
