@@ -1,4 +1,4 @@
-## Copyright (C) 2007 John W. Eaton
+## Copyright (C) 2007, 2008 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -30,7 +30,7 @@ function retval = cast (val, typ)
     if (ischar (typ))
       if (any (strcmp (typ, {"int8"; "uint8"; "int16"; "uint16";
 			     "int32"; "uint32"; "int64"; "uint64";
-			     "double"; "single"})))
+			     "double"; "single"; "logical"})))
 	retval = feval (typ, val);
       else
 	error ("cast: type name `%s' is not a built-in type", typ);
