@@ -1,4 +1,4 @@
-## Copyright (C) 2005, 2006, 2007 Sren Hauberg
+## Copyright (C) 2005, 2006, 2007, 2008 Sren Hauberg
 ## 
 ## This file is part of Octave.
 ##
@@ -101,6 +101,29 @@
 ## @noindent
 ## splits the list of installed packages into those who are installed by
 ## the current user, and those installed by the system administrator.
+## @item describe
+## Show a short description of the named installed packages, with the option
+## '-verbose' also list functions provided by the package, e.g.:
+## @example
+##  pkg describe -verbose all
+## @end example
+## @noindent
+## will describe all installed packages and the functions they provide.
+## If one output is requested a cell of structure containing the
+## description and list of functions of each package is returned as
+## output rather than printed on screen:
+## @example
+##  desc = pkg ("describe", "secs1d", "image")
+## @end example
+## @noindent
+## If any of the requested packages is not installed, pkg returns an
+## error, unless a second output is requested:
+## @example
+##  [ desc, flag] = pkg ("describe", "secs1d", "image")
+## @end example
+## @noindent
+## @var{flag} will take one of the values "Not installed", "Loaded" or
+## "Not loaded" for each of the named packages.
 ## @item prefix
 ## Set the installation prefix directory. For example,
 ## @example
@@ -179,7 +202,7 @@ function [local_packages, global_packages] = pkg (varargin)
   persistent user_prefix = false;
   persistent prefix = -1;
   persistent archprefix = -1;
-  persistent local_list = tilde_expand (fullfile("~", ".octave_packages"));
+  persistent local_list = tilde_expand (fullfile ("~", ".octave_packages"));
   persistent global_list = fullfile (OCTAVE_HOME (), "share", "octave",
 				     "octave_packages");
   mlock ();
@@ -189,7 +212,8 @@ function [local_packages, global_packages] = pkg (varargin)
   if (prefix == -1)
     if (global_install)
       prefix = fullfile (OCTAVE_HOME (), "share", "octave", "packages");
-      archprefix = fullfile (octave_config_info ("libexecdir"), "octave", "packages");
+      archprefix = fullfile (octave_config_info ("libexecdir"),
+			     "octave", "packages");
     else
       prefix = fullfile ("~", "octave");
       archprefix = prefix;
@@ -198,6 +222,9 @@ function [local_packages, global_packages] = pkg (varargin)
     archprefix = tilde_expand (archprefix);
   endif
 
+  available_actions = {"list", "install", "uninstall", "load", ...
+		       "unload", "prefix", "local_list", ...
+		       "global_list", "rebuild", "build","describe"}; 
   ## Handle input
   if (length (varargin) == 0 || ! iscellstr (varargin))
     print_usage ();
@@ -221,14 +248,16 @@ function [local_packages, global_packages] = pkg (varargin)
 	global_install = false;
 	if (! user_prefix)
 	  prefix = tilde_expand (fullfile ("~", "octave"));
+	  archprefix = prefix;
 	endif
       case "-global"
 	global_install = true;
 	if (! user_prefix)
 	  prefix = fullfile (OCTAVE_HOME (), "share", "octave", "packages");
+	  archprefix = fullfile (octave_config_info ("libexecdir"),
+				 "octave", "packages");
 	endif
-      case {"list", "install", "uninstall", "load", "unload", "prefix", ...
-	    "local_list", "global_list", "rebuild", "build"}
+      case available_actions
 	if (strcmp (action, "none"))
 	  action = varargin{i};
 	else
@@ -316,7 +345,7 @@ function [local_packages, global_packages] = pkg (varargin)
 	  local_list = absolute_pathname (files{1});
 	catch
 	  ## Force file to be created
-	  fclose (fopen (files{1}, 'wt'));
+	  fclose (fopen (files{1}, "wt"));
 	  local_list = absolute_pathname (files{1});
 	end_try_catch
       else
@@ -333,7 +362,7 @@ function [local_packages, global_packages] = pkg (varargin)
 	  global_list = absolute_pathname (files{1});
 	catch
 	  ## Force file to be created
-	  fclose (fopen (files{1}, 'wt'));
+	  fclose (fopen (files{1}, "wt"));
 	  global_list = absolute_pathname (files{1});
 	end_try_catch
       else
@@ -365,6 +394,28 @@ function [local_packages, global_packages] = pkg (varargin)
       endif
       build (files, deps, auto, verbose);
 
+    case "describe"
+      if (length (files) == 0)
+	error ("you must specify at least one package or 'all' when calling 'pkg describe'");
+      endif
+      ## XXX FIXME: the name of the output variables is inconsistent
+      ##            with their content
+      switch (nargout)
+	case 0
+	  describe (files, verbose, local_list, global_list);
+	case 1
+	  pkg_desc_list = describe (files, verbose, local_list, ...
+				    global_list);
+	  local_packages = pkg_desc_list;
+	case 2
+	  [pkg_desc_list, flag] = describe (files, verbose, local_list, ...
+					    global_list);
+	  local_packages  = pkg_desc_list;
+	  global_packages = flag;
+	otherwise
+	  error ("you can request at most two outputs when calling 'pkg describe'");
+      endswitch
+		
     otherwise
       error ("you must specify a valid action for 'pkg'. See 'help pkg' for details");
   endswitch
@@ -551,45 +602,54 @@ function install (files, handle_deps, autoload, prefix, archprefix, verbose,
 	if (length (dirlist) > 3)
 	  error ("bundles of packages are not allowed")
 	endif
+      endif
 
+      ## The filename pointed to an uncompressed package to begin with
+      if (exist (tgz, "dir"))
+	dirlist = {".", "..", tgz};
+      endif
+
+      if (exist (tgz, "file") || exist (tgz, "dir"))
 	## the two first entries of dirlist are "." and ".."
-	for k = 3:length (dirlist)
-	  packdir = fullfile (tmpdir, dirlist{k});
-	  packdirs{end+1} = packdir;
-
-	  ## Make sure the package contains necessary files
-	  verify_directory (packdir);
-
-	  ## Read the DESCRIPTION file
-	  filename = fullfile (packdir, "DESCRIPTION");
-	  desc = get_description (filename);
-
-	  ## Verify that package name corresponds with filename
-	  [dummy, nm] = fileparts (tgz); 
-	  if ((length (nm) >= length (desc.name))
-	      && ! strcmp (desc.name, nm(1:length(desc.name))))
-	    error ("package name '%s' doesn't correspond to its filename '%s'", 
-		   desc.name, nm);
+	if (exist (tgz, "file"))
+	  packdir = fullfile (tmpdir, dirlist{3});
+	else
+	  packdir = fullfile (pwd(), dirlist{3});
+	endif
+	packdirs{end+1} = packdir;
+	
+	## Make sure the package contains necessary files
+	verify_directory (packdir);
+	
+	## Read the DESCRIPTION file
+	filename = fullfile (packdir, "DESCRIPTION");
+	desc = get_description (filename);
+	
+	## Verify that package name corresponds with filename
+	[dummy, nm] = fileparts (tgz); 
+	if ((length (nm) >= length (desc.name))
+	    && ! strcmp (desc.name, nm(1:length(desc.name))))
+	  error ("package name '%s' doesn't correspond to its filename '%s'", 
+		 desc.name, nm);
+	endif
+	
+	## Set default installation directory
+	desc.dir = fullfile (prefix, strcat (desc.name, "-", desc.version));
+	
+	## Set default architectire dependent installation directory
+	desc.archprefix = fullfile (archprefix, strcat (desc.name, "-",
+							desc.version));
+	
+	## Save desc
+	descriptions{end+1} = desc;
+	
+	## Are any of the new packages already installed?
+	## If so we'll remove the old version.
+	for j = 1:length (packages)
+	  if (strcmp (packages{j}.name, desc.name))
+	    packages_to_uninstall(end+1) = j;
 	  endif
-
-	  ## Set default installation directory
-	  desc.dir = fullfile (prefix, strcat (desc.name, "-", desc.version));
-
-	  ## Set default architectire dependent installation directory
-	  desc.archprefix = fullfile (archprefix, strcat (desc.name, "-",
-							  desc.version));
-
-	  ## Save desc
-	  descriptions{end+1} = desc;
-
-	  ## Are any of the new packages already installed?
-	  ## If so we'll remove the old version.
-	  for j = 1:length (packages)
-	    if (strcmp (packages{j}.name, desc.name))
-	      packages_to_uninstall(end+1) = j;
-	    endif
-	  endfor
-	endfor        
+	endfor
       endif
     endfor
   catch
@@ -853,7 +913,7 @@ function uninstall (pkgnames, handle_deps, verbose, local_list,
     ## If an 'on_uninstall.m' exist, call it!
     if (exist (fullfile (desc.dir, "packinfo", "on_uninstall.m"), "file"))
       wd = pwd ();
-      cd (fullfile(desc.dir, "packinfo"));
+      cd (fullfile (desc.dir, "packinfo"));
       on_uninstall (desc);
       cd (wd);
     endif
@@ -900,12 +960,142 @@ function uninstall (pkgnames, handle_deps, verbose, local_list,
 
 endfunction
 
+function [pkg_desc_list, flag] = describe (pkgnames, verbose, 
+					   local_list, global_list)
+
+  ## Get the list of installed packages
+  installed_pkgs_lst = installed_packages(local_list, global_list);
+  num_packages = length (installed_pkgs_lst);
+  
+
+  describe_all = false;
+  if (any (strcmp ("all", pkgnames)))
+    describe_all = true;
+    flag{1:num_packages} = "Not Loaded";
+    num_pkgnames = num_packages;
+  else
+    num_pkgnames = length (pkgnames);
+    flag{1:num_pkgnames} = "Not installed";
+  endif
+
+  for i = 1:num_packages
+    curr_name= installed_pkgs_lst{i}.name;
+    if (describe_all)
+      name_pos = i;
+    else
+      name_pos = find(strcmp (curr_name, pkgnames));
+    endif
+
+    if (! isempty (name_pos))
+      if (installed_pkgs_lst{i}.loaded)
+	flag{name_pos} = "Loaded";
+      else
+	flag{name_pos} = "Not loaded";
+      endif
+
+      pkg_desc_list{name_pos}.name = installed_pkgs_lst{i}.name;
+      pkg_desc_list{name_pos}.description = installed_pkgs_lst{i}.description;
+      pkg_desc_list{name_pos}.provides = parse_pkg_idx (installed_pkgs_lst{i}.dir);
+
+    endif
+  endfor
+
+  non_inst = find (strcmp (flag, "Not installed"));
+  if (! isempty (non_inst) && nargout < 2)
+    non_inst_str = sprintf (" %s ", pkgnames{non_inst});
+    error ("some packages are not installed: %s", non_inst_str);
+  endif
+
+  if (nargout == 0)
+    for i = 1:num_pkgnames
+      print_package_description (pkg_desc_list{i}.name, 
+				 pkg_desc_list{i}.provides,  
+				 pkg_desc_list{i}.description,
+				 flag{i}, verbose);
+    endfor
+  endif
+
+endfunction
+
 ##########################################################
 ##        A U X I L I A R Y    F U N C T I O N S        ##
 ##########################################################
 
+## This function reads an INDEX file
+function [pkg_idx_struct] = parse_pkg_idx (packdir)
+
+  index_file = fullfile (packdir, "packinfo", "INDEX");
+
+  if (! exist (index_file, "file"))
+    error ("could not find any INDEX file in directory %s, try 'pkg rebuild all' to generate missing INDEX files", packdir);
+  endif    
+
+    
+  [fid, msg] = fopen (index_file, "r");
+  if (fid == -1)
+    error ("the INDEX file %s could not be read: %s", 
+	   index_file, msg);
+  endif
+
+  cat_num = 1;
+  pkg_idx_struct{1}.category = "Uncategorized";
+  pkg_idx_struct{1}.functions = {};
+
+  line = fgetl (fid);
+  while (isempty (strfind (line, ">>")) && ! feof (fid))
+    line = fgetl (fid);
+  endwhile
+
+  while (! feof (fid) || line != -1)
+    if (! any (! isspace (line)) || line(1) == "#" || any (line == "="))
+      ## Comments,  blank lines or comments about unimplemented 
+      ## functions: do nothing
+      ## XXX: probably comments and pointers to external functions
+      ## could be treated better when printing to screen?
+    elseif (! isempty (strfind (line, ">>")))
+      ## Skip package name and description as they are in
+      ## DESCRIPTION already
+    elseif (! isspace (line(1)))
+      ## Category
+      if (! isempty (pkg_idx_struct{cat_num}.functions))
+	pkg_idx_struct{++cat_num}.functions = {};
+      endif
+      pkg_idx_struct{cat_num}.category = deblank (line);
+    else
+      ## Function names
+      while (any (! isspace (line)))
+	[fun_name, line] = strtok (line);
+	pkg_idx_struct{cat_num}.functions{end+1} = deblank (fun_name);
+      endwhile
+    endif
+    line = fgetl (fid);
+  endwhile
+  fclose (fid);
+endfunction
+
+function print_package_description (pkg_name, pkg_idx_struct, 
+				    pkg_desc, status, verbose)
+
+  printf ("---\nPackage name:\n\t%s\n", pkg_name);
+  printf ("Short description:\n\t%s\n", pkg_desc);
+  printf ("Status:\n\t%s\n", status);
+  if (verbose)
+    printf ("---\nProvides:\n");    
+    for i = 1:length(pkg_idx_struct)
+      if (! isempty (pkg_idx_struct{i}.functions))
+	printf ("%s\n", pkg_idx_struct{i}.category);
+	for j = 1:length(pkg_idx_struct{i}.functions)
+	  printf ("\t%s\n", pkg_idx_struct{i}.functions{j});
+	endfor
+      endif
+    endfor
+  endif
+
+endfunction
+
+
 function pth = absolute_pathname (pth)
-  [status, msg, msgid] = fileattrib(pth);
+  [status, msg, msgid] = fileattrib (pth);
   if (status != 1)
     error ("could not find the file or path %s", pth);
   else
@@ -1038,7 +1228,7 @@ function configure_make (desc, packdir, verbose)
       if (isempty (getenv ("RANLIB")))
         flags = strcat (flags, " RANLIB=\"", octave_config_info ("RANLIB"), "\"");
       endif
-      [status, output] = shell (strcat ("cd ", src, "; ./configure --prefix=\"",
+      [status, output] = shell (strcat ("cd '", src, "'; ./configure --prefix=\"",
                                         desc.dir, "\"", flags));
       if (status != 0)
 	rm_rf (desc.dir);
@@ -1052,7 +1242,7 @@ function configure_make (desc, packdir, verbose)
     ## make
     if (exist (fullfile (src, "Makefile"), "file"))
       [status, output] = shell (strcat ("export INSTALLDIR=\"", desc.dir,
-					 "\"; make -C ", src));
+ 					 "\"; make -C '", src, "'"));
       if (status != 0)
 	rm_rf (desc.dir);
 	error ("'make' returned the following error: %s", output);
@@ -1091,38 +1281,27 @@ function configure_make (desc, packdir, verbose)
       m = dir (fullfile (src, "*.m"));
       oct = dir (fullfile (src, "*.oct"));
       mex = dir (fullfile (src, "*.mex"));
-      archdependent = "";
-      archindependent = "";
-      filenames = "";
-      if (length (m) > 0)
-	filenames = sprintf (fullfile (src, "%s "), m.name);
-      endif
-      if (length (oct) > 0)
-	filenames = strcat (filenames, " ", sprintf(fullfile(src, "%s "), ...
-						    oct.name));
-      endif
-      if (length (mex) > 0)
-	filenames = strcat (filenames, " ", sprintf(fullfile(src, "%s "), ...
-						    mex.name));
-      endif
-      filenames = split_by (filenames, " ");
+
+      filenames = cellfun (@(x) fullfile (src, x),
+			   {m.name, oct.name, mex.name},
+			   "UniformOutput", false);
     endif
 
     ## Split into architecture dependent and independent files
     if (isempty (filenames))
       idx = [];
     else
-      idx = cellfun (@(x) is_architecture_dependent (x), filenames);
+      idx = cellfun (@is_architecture_dependent, filenames);
     endif
     archdependent = filenames (idx);
     archindependent = filenames (!idx);
 
     ## Copy the files
-    if (! all (isspace (filenames)))
+    if (! all (isspace ([filenames{:}])))
 	if (! exist (instdir, "dir")) 
 	  mkdir (instdir);
 	endif
-	if (! all (isspace (archindependent)))
+	if (! all (isspace ([archindependent{:}])))
 	  if (verbose)
 	    printf ("copyfile");
 	    printf (" %s", archindependent{:});
@@ -1134,7 +1313,7 @@ function configure_make (desc, packdir, verbose)
 	    error ("Couldn't copy files from 'src' to 'inst': %s", output);
 	  endif
         endif
-	if (! all (isspace (archdependent)))
+	if (! all (isspace ([archdependent{:}])))
 	  if (verbose)
 	    printf ("copyfile");
 	    printf (" %s", archdependent{:});
@@ -1192,16 +1371,16 @@ function create_pkgadddel (desc, packdir, nm, global_install)
 
   if (archfid >= 0 && instfid >= 0)
     ## Search all dot-m files for PKG commands
-    lst = dir (fullfile(packdir, "inst", "*.m"));
+    lst = dir (fullfile (packdir, "inst", "*.m"));
     for i = 1:length (lst)
-      nam = fullfile(packdir, "inst", lst(i).name);
+      nam = fullfile (packdir, "inst", lst(i).name);
       fwrite (instfid, extract_pkg (nam, ['^[#%][#%]* *' nm ': *(.*)$']));
     endfor
 
     ## Search all C++ source files for PKG commands
-    lst = dir (fullfile(packdir, "src", "*.cc"));
+    lst = dir (fullfile (packdir, "src", "*.cc"));
     for i = 1:length (lst)
-      nam = fullfile(packdir, "src", lst(i).name);
+      nam = fullfile (packdir, "src", lst(i).name);
       fwrite (archfid, extract_pkg (nam, ['^//* *' nm ': *(.*)$']));
       fwrite (archfid, extract_pkg (nam, ['^/\** *' nm ': *(.*) *\*/$']));
     endfor
@@ -1335,9 +1514,9 @@ function copy_files (desc, packdir, global_install)
   endif
 
   ## If the file ChangeLog exists, copy it
-  fChangeLog = fullfile(packdir, "ChangeLog");
-  if (exist (fChangeLog, "file"))
-    [status, output] = copyfile (fChangeLog, packinfo);
+  changelog_file = fullfile (packdir, "ChangeLog");
+  if (exist (changelog_file, "file"))
+    [status, output] = copyfile (changelog_file, packinfo);
     if (status != 1)
       rm_rf (desc.dir);
       rm_rf (octfiledir);
@@ -1346,9 +1525,9 @@ function copy_files (desc, packdir, global_install)
   endif
 
   ## Is there an INDEX file to copy or should we generate one?
-  fINDEX = fullfile (packdir, "INDEX");
-  if (exist(fINDEX, "file"))
-    [status, output] = copyfile (fINDEX, packinfo);
+  index_file = fullfile (packdir, "INDEX");
+  if (exist(index_file, "file"))
+    [status, output] = copyfile (index_file, packinfo);
     if (status != 1)
       rm_rf (desc.dir);
       rm_rf (octfiledir);
@@ -1356,7 +1535,7 @@ function copy_files (desc, packdir, global_install)
     endif
   else
     try
-      write_INDEX (desc, fullfile (packdir, "inst"),
+      write_index (desc, fullfile (packdir, "inst"),
 		   fullfile (packinfo, "INDEX"), global_install);
     catch
       rm_rf (desc.dir);
@@ -1366,7 +1545,7 @@ function copy_files (desc, packdir, global_install)
   endif
 
   ## Is there an 'on_uninstall.m' to install?
-  fon_uninstall = fullfile(packdir, "on_uninstall.m");
+  fon_uninstall = fullfile (packdir, "on_uninstall.m");
   if (exist (fon_uninstall, "file"))
     [status, output] = copyfile (fon_uninstall, packinfo);
     if (status != 1)
@@ -1407,8 +1586,7 @@ function finish_installation (desc, packdir, global_install)
   endif
 endfunction
 
-## This function makes sure the package contains the
-## essential files.
+## Make sure the package contains the essential files.
 function verify_directory (dir)
   needed_files = {"COPYING", "DESCRIPTION"};
   for f = needed_files
@@ -1418,7 +1596,7 @@ function verify_directory (dir)
   endfor
 endfunction
 
-## This function parses the DESCRIPTION file
+## Parse the DESCRIPTION file
 function desc = get_description (filename)
   [fid, msg] = fopen (filename, "r");
   if (fid == -1)
@@ -1444,7 +1622,7 @@ function desc = get_description (filename)
       else
 	colon = colon(1);
 	keyword = tolower (strip (line(1:colon-1)));
-	value   = strip (line (colon+1:end));
+	value = strip (line (colon+1:end));
 	if (length (value) == 0)
 	    fclose (fid);
 	    error ("the keyword %s has an empty value", desc.keywords{end});
@@ -1473,7 +1651,7 @@ function desc = get_description (filename)
   desc.name = tolower (desc.name);
 endfunction
 
-## Makes sure the version string v is a valid x.y.z version string
+## Make sure the version string v is a valid x.y.z version string
 ## Examples: "0.1" => "0.1.0", "monkey" => error(...)
 function out = fix_version (v)
   dots = find (v == ".");
@@ -1487,7 +1665,7 @@ function out = fix_version (v)
   elseif (length (dots) == 2)
     major = str2num (v(1:dots(1)-1));
     minor = str2num (v(dots(1)+1:dots(2)-1));
-    rev   = str2num (v(dots(2)+1:end));
+    rev = str2num (v(dots(2)+1:end));
     if (length (major) != 0 && length (minor) != 0 && length (rev) != 0)
       out = sprintf ("%d.%d.%d", major, minor, rev);
       return;
@@ -1496,7 +1674,7 @@ function out = fix_version (v)
   error ("bad version string: %s", v);
 endfunction
 
-## Makes sure the depends field is of the right format.
+## Make sure the depends field is of the right format.
 ## This function returns a cell of structures with the following fields:
 ##   package, version, operator
 function deps_cell = fix_depends (depends)
@@ -1544,7 +1722,7 @@ function deps_cell = fix_depends (depends)
   endfor
 endfunction
 
-## Strips the text of spaces from the right
+## Strip the text of spaces from the right
 ## Example: "  hello world  " => "  hello world" (XXX: is this the same as deblank?)
 function text = rstrip (text)
   chars = find (! isspace (text));
@@ -1556,7 +1734,7 @@ function text = rstrip (text)
   endif
 endfunction
 
-## Strips the text of spaces from the left and the right
+## Strip the text of spaces from the left and the right
 ## Example: "  hello world  " => "hello world"
 function text = strip (text)
   chars = find (! isspace (text));
@@ -1567,7 +1745,7 @@ function text = strip (text)
   endif
 endfunction
 
-## Splits the text into a cell array of strings by sep
+## Split the text into a cell array of strings by sep
 ## Example: "A, B" => {"A", "B"} (with sep = ",")
 function out = split_by (text, sep)
   text_matrix = split (text, sep);
@@ -1578,11 +1756,11 @@ function out = split_by (text, sep)
   endfor
 endfunction
 
-## Creates an INDEX file for a package that doesn't provide one.
+## Create an INDEX file for a package that doesn't provide one.
 ##   'desc'  describes the package.
-##   'dir'   is the 'inst' direcotyr in temporary directory.
-##   'INDEX' is the name (including path) of resulting INDEX file.
-function write_INDEX (desc, dir, INDEX, global_install)
+##   'dir'   is the 'inst' directory in temporary directory.
+##   'index_file' is the name (including path) of resulting INDEX file.
+function write_index (desc, dir, index_file, global_install)
   ## Get names of functions in dir
   [files, err, msg] = readdir (dir);
   if (err)
@@ -1620,9 +1798,9 @@ function write_INDEX (desc, dir, INDEX, global_install)
   endif
 
   ## Write INDEX
-  fid = fopen (INDEX, "w");
+  fid = fopen (index_file, "w");
   if (fid == -1)
-    error ("couldn't open %s for writing.", INDEX);
+    error ("couldn't open %s for writing.", index_file);
   endif
   fprintf (fid, "%s >> %s\n", desc.name, desc.title);
   fprintf (fid, "%s\n", categories{1});
@@ -2030,13 +2208,13 @@ function load_packages_and_dependencies (idx, handle_deps, installed_pkgs_lst,
     ndir = installed_pkgs_lst{i}.dir;
     dirs{end+1} = ndir;
     if (exist (fullfile (dirs{end}, "bin"), "dir"))
-      execpath = strcat (fullfile(dirs{end}, "bin"), ":", execpath);
+      execpath = strcat (fullfile (dirs{end}, "bin"), ":", execpath);
     endif
     tmpdir = getarchdir (installed_pkgs_lst{i});
     if (exist (tmpdir, "dir"))
       dirs{end + 1} = tmpdir;
       if (exist (fullfile (dirs{end}, "bin"), "dir"))
-        execpath = strcat (fullfile(dirs{end}, "bin"), ":", execpath);
+        execpath = strcat (fullfile (dirs{end}, "bin"), ":", execpath);
       endif
     endif
   endfor
