@@ -1001,7 +1001,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
 
     ## This is need to prevent warnings for rotations in 3D plots, while
     ## allowing colorbars with contours..
-    if (nd == 2 || data_idx > 1)
+    if (nd == 2 || (data_idx > 1 && !view_map))
       fputs (plot_stream, "set pm3d implicit;\n");
     else
       fputs (plot_stream, "set pm3d explicit;\n");
@@ -1013,7 +1013,7 @@ function __go_draw_axes__ (h, plot_stream, enhanced, mono)
       fputs (plot_stream, "unset hidden3d;\n");
     endif
 
-    have_data = (! (isempty (data) || any (cellfun (@isempty, data))));
+    have_data = (! (isempty (data) || all (cellfun (@isempty, data))));
 
     if (isempty (xlim))
       return;
@@ -1447,15 +1447,19 @@ function __gnuplot_write_data__ (plot_stream, data, nd, parametric, cdata)
       n = columns (data);
       have_nans = true;
       num_nan_elts = numel (nan_elts);
-      k = 1;
-      for i = 1:n
-	if (have_nans && i == nan_elts(k))
-	  fputs (plot_stream, "\n");
-	  have_nans = ++k <= num_nan_elts;
-	else
-	  fprintf (plot_stream, fmt, data(:,i));
-	endif
-      endfor
+      if (num_nan_elts == n)
+	fputs (plot_stream, "Inf Inf\n");
+      else
+	k = 1;
+	for i = 1:n
+	  if (have_nans && i == nan_elts(k))
+	    fputs (plot_stream, "\n");
+	    have_nans = ++k <= num_nan_elts;
+	  else
+	    fprintf (plot_stream, fmt, data(:,i));
+	  endif
+	endfor
+      endif
     endif
   elseif (nd == 3)
     ## FIXME -- handle NaNs here too?
