@@ -20,14 +20,18 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} grid (@var{arg})
 ## @deftypefnx {Function File} {} grid ("minor", @var{arg2})
+## @deftypefnx {Function File} {} grid (@var{hax}, @dots{})
 ## Force the display of a grid on the plot.
-## The argument may be either @code{"on"} or @code{"off"}.  If it is
-## omitted, the current grid state is toggled.
+## The argument may be either @code{"on"}, or @code{"off"}.
+## If it is omitted, the current grid state is toggled.
 ##
 ## If @var{arg} is @code{"minor"} then the minor grid is toggled.  When
 ## using a minor grid a second argument @var{arg2} is allowed, which can
 ## be either @code{"on"} or @code{"off"} to explicitly set the state of
 ## the minor grid.
+##
+## If the first argument is an axis handle, @var{hax}, operate on the
+## specified axis object.
 ## @seealso{plot}
 ## @end deftypefn
 
@@ -42,7 +46,7 @@ function grid (varargin)
 
   [ax, varargin, nargs] = __plt_get_axis_arg__ ("grid", varargin{:});
 
-  if (nargs > 1)
+  if (nargs > 2)
     print_usage ();
   elseif (nargs == 0)
     grid_on = ! grid_on;
@@ -54,10 +58,22 @@ function grid (varargin)
       elseif (strcmp ("on", x))
 	grid_on = true;
       elseif (strcmp ("minor", x))
-	minor_on = ! minor_on;
-	if (minor_on)
-	  grid_on = true;
-	endif
+        if (nargs == 2)
+          x2 = varargin{2};
+          if (strcmpi (x2, "on"))
+            minor_on = true;
+            grid_on=true;
+          elseif (strcmpi (x2, "off"))
+            minor_on = false;
+          else
+            print_usage ();
+          endif
+        else
+          minor_on = ! minor_on
+          if (minor_on)
+            grid_on = true;
+          endif
+        endif
       else
 	print_usage ();
       endif
