@@ -1,4 +1,4 @@
-## Copyright (C) 1999, 2005, 2006, 2007 Daniel Heiserer
+## Copyright (C) 1999, 2005, 2006, 2007, 2008 Daniel Heiserer
 ## Copyright (C) 2001 Laurent Mazet
 ##
 ## This file is part of Octave.
@@ -82,10 +82,17 @@
 ##     Metafont
 ##   @item png
 ##     Portable network graphics
+##   @item jpg
+##   @itemx jpeg
+##     JPEG image
+##   @item gif
+##     GIF image
 ##   @item pbm
 ##     PBMplus
 ##   @item svg
 ##     Scalable vector graphics
+##   @item pdf
+##     Portable document format
 ##   @end table
 ##
 ##   Other devices are supported by "convert" from ImageMagick.  Type
@@ -216,10 +223,11 @@ function print (varargin)
   endif
 
   ## check if we have to use convert
-  dev_list = {"aifm", "corel", "fig", "png", "pbm", "dxf", "mf", "svg", ...
-	      "hpgl", "ps", "ps2", "psc", "psc2", "eps", "eps2", ...
-	      "epsc", "epsc2", "emf", "pstex", "pslatex", ...
-	      "epslatex", "epslatexstandalone"};
+  dev_list = {"aifm", "corel", "fig", "png", "jpg", "jpeg", ...
+	      "gif", "pbm", "dxf", "mf", "svg", "hpgl", ...
+	      "ps", "ps2", "psc", "psc2", "eps", "eps2", ...
+	      "epsc", "epsc2", "emf", "pdf", "pslatex", ...
+	      "epslatex", "epslatexstandalone", "pstex"};
   convertname = "";
   [idx, errmsg] = cellidx (dev_list, dev);
   if (! idx)
@@ -335,7 +343,12 @@ function print (varargin)
 
     new_terminal = strcat ("emf ", options);
 
-  elseif (strcmp (dev, "png") || strcmp (dev, "pbm"))
+  elseif (strcmp (dev, "png") || strcmp (dev, "gif")
+	  || strcmp (dev, "jpg") || strcmp (dev, "jpeg")
+	  || strcmp (dev, "pbm"))
+    if (strcmp (dev, "jpg"))
+      dev = "jpeg";
+    endif
     ## Portable network graphics, PBMplus
 
     ## FIXME -- New PNG interface takes color as "xRRGGBB"
@@ -356,7 +369,7 @@ function print (varargin)
     else
       options = strcat (" size ", size);
     endif
-    new_terminal = strcat ("png", options);
+    new_terminal = strcat (dev, options);
 
   elseif (strcmp (dev, "dxf") || strcmp (dev, "mf") || strcmp (dev, "hpgl"))
     ## AutoCad DXF, METAFONT, HPGL
@@ -369,13 +382,37 @@ function print (varargin)
       options = strcat (" size ", size);
     endif
     new_terminal = strcat ("svg", options);
+    
+  elseif (strcmp (dev, "pdf"))
+    ## Portable Document format
+    options = " ";
+    if (use_color >= 0)
+      options = "color";
+    else
+      options = "mono";
+    endif
+    if (force_solid > 0)
+       options = strcat (options, " solid");
+    elseif (force_solid < 0)
+      options = strcat (options, " dashed");
+    endif
+    if (! isempty (font))
+      options = strcat (options, "\"", font, "\" ");
+    endif
+    if (! isempty (fontsize))
+      options = strcat (options, " ", fontsize);
+    endif
+
+    new_terminal = strcat ("pdf ", options);
 
   endif
 
+  mono = use_color < 0;
+
   if (debug)
-    drawnow (new_terminal, name, debug_file);
+    drawnow (new_terminal, name, mono, debug_file);
   else
-    drawnow (new_terminal, name);
+    drawnow (new_terminal, name, mono);
   endif
 
   if (! isempty (convertname))
