@@ -1,13 +1,13 @@
 /*
 
-Copyright (C) 2005 David Bateman
+Copyright (C) 2005, 2006, 2007, 2008 David Bateman
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +15,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -60,7 +59,7 @@ Remove any previously cached matrix type, and mark type as unknown\n\
 Mark the matrix as full.\n\
 \n\
 @item 'positive definite'\n\
-Full positive definite matrix.\n\
+Probable full positive definite matrix.\n\
 \n\
 @item 'diagonal'\n\
 Diagonal Matrix. (Sparse matrices only)\n\
@@ -84,8 +83,8 @@ vector @var{perm}.\n\
 @itemx 'banded positive definite'\n\
 Banded matrix with the band size of @var{nl} below the diagonal and @var{nu} above\n\
 it. If @var{nl} and @var{nu} are 1, then the matrix is tridiagonal and treated\n\
-with specialized code. In addition the matrix can be marked as positive definite\n\
-(Sparse matrices only)\n\
+with specialized code. In addition the matrix can be marked as probably a\n\
+positive definite (Sparse matrices only)\n\
 \n\
 @item 'singular'\n\
 The matrix is assumed to be singular and will be treated with a minimum norm solution\n\
@@ -96,8 +95,16 @@ Note that the matrix type will be discovered automatically on the first attempt
 solve a linear equation involving @var{a}. Therefore @code{matrix_type} is only\n\
 useful to give Octave hints of the matrix type. Incorrectly defining the\n\
 matrix type will result in incorrect results from solutions of linear equations,\n\
-and so it is entirely the responsibility of the user to correctly indentify the\n\
+and so it is entirely the responsibility of the user to correctly identify the\n\
 matrix type.\n\
+\n\
+Also the test for positive definiteness is a low cost test for a hermitian\n\
+matrix with a real positive diagonal. This does not guarantee that the matrix\n\
+is positive definite, but only that it is a probable candidate. When such a\n\
+matrix is factorized, a Cholesky factorization is first attempted, and if\n\
+that fails the matrix is then treated with an LU factorization. Once the\n\
+matrix has been factorized, @code{matrix_type} will return the correct\n\
+classification of the matrix.\n\
 @end deftypefn")
 {
   int nargin = args.length ();
